@@ -1,16 +1,16 @@
 package File::Patch::Undoable;
 
-our $DATE = '2015-09-03'; # DATE
-our $VERSION = '0.06'; # VERSION
+our $DATE = '2016-06-09'; # DATE
+our $VERSION = '0.07'; # VERSION
 
 use 5.010001;
 use strict;
 use warnings;
 use Log::Any::IfLOG '$log';
 
-use Builtin::Logged qw(system);
 use Capture::Tiny qw(capture);
 use File::Temp qw(tempfile);
+use IPC::System::Options 'system', -log=>1;
 use Proc::ChildError qw(explain_child_error);
 
 our %SPEC;
@@ -178,24 +178,10 @@ File::Patch::Undoable - Patch a file, with undo support
 
 =head1 VERSION
 
-This document describes version 0.06 of File::Patch::Undoable (from Perl distribution File-Patch-Undoable), released on 2015-09-03.
-
-=head1 FAQ
-
-=head2 Why use the patch program? Why not use a Perl module like Text::Patch?
-
-The B<patch> program has many nice features that L<Text::Patch> lacks, e.g.
-applying reverse patch (needed to check fixed state and to undo), autodetection
-of patch type, ignoring whitespace and fuzz factor, etc.
+This document describes version 0.07 of File::Patch::Undoable (from Perl distribution File-Patch-Undoable), released on 2016-06-09.
 
 =head1 KNOWN ISSUES
 
-=head1 SEE ALSO
-
-L<Rinci::Transaction>
-
-L<Text::Patch>, L<PatchReader>, L<Text::Patch::Rred>
-
 =head1 FUNCTIONS
 
 
@@ -217,6 +203,8 @@ Fixed state: file exists, patch file exists, and patch has been applied.
 
 Fixable state: file exists, patch file exists, and patch has not been applied.
 
+This function is not exported.
+
 This function is idempotent (repeated invocations with same arguments has the same effect as single invocation). This function supports transactions.
 
 
@@ -277,6 +265,14 @@ that contains extra information.
 
 Return value:  (any)
 
+=head1 FAQ
+
+=head2 Why use the patch program? Why not use a Perl module like Text::Patch?
+
+The B<patch> program has many nice features that L<Text::Patch> lacks, e.g.
+applying reverse patch (needed to check fixed state and to undo), autodetection
+of patch type, ignoring whitespace and fuzz factor, etc.
+
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/File-Patch-Undoable>.
@@ -293,13 +289,19 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
+=head1 SEE ALSO
+
+L<Rinci::Transaction>
+
+L<Text::Patch>, L<PatchReader>, L<Text::Patch::Rred>
+
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by perlancar@cpan.org.
+This software is copyright (c) 2016 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
